==> onos-yang-serializers-xml-2.3-sources.jar: org/onosproject/yang/gen/v1/choicecase/rev20160624/choicecase/snack/sportsarena/bear/addon/snacks/chips/DefaultBanana.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.choicecase.rev20160624.choicecase.snack.sportsarena.bear.addon.snacks.chips;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;
import org.onosproject.yang.model.MultiInstanceObject;

/**
 * Represents the implementation of banana.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultBanana extends InnerModelObject 
        implements Banana, MultiInstanceObject<BananaKeys> {
    protected String l1;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public String l1() {
        return l1;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void l1(String l1) {
        valueLeafFlags.set(LeafIdentifier.L1.getLeafIndex());
        this.l1 = l1;
    }

    @Override
    public int hashCode() {
        return Objects.hash(l1, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultBanana) {
            DefaultBanana other = (DefaultBanana) obj;
            return
                Objects.equals(l1, other.l1) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("l1=" + l1)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultBanana.
     */
    public DefaultBanana() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-serializers-xml-2.3.1-sources.jar: org/onosproject/yang/gen/v1/choicecase/rev20160624/choicecase/snack/sportsarena/bear/addon/snacks/chips/DefaultBanana.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.choicecase.rev20160624.choicecase.snack.sportsarena.bear.addon.snacks.chips;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;
import org.onosproject.yang.model.MultiInstanceObject;

/**
 * Represents the implementation of banana.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultBanana extends InnerModelObject 
        implements Banana, MultiInstanceObject<BananaKeys> {
    protected String l1;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public String l1() {
        return l1;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void l1(String l1) {
        valueLeafFlags.set(LeafIdentifier.L1.getLeafIndex());
        this.l1 = l1;
    }

    @Override
    public int hashCode() {
        return Objects.hash(l1, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultBanana) {
            DefaultBanana other = (DefaultBanana) obj;
            return
                Objects.deepEquals(l1, other.l1) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("l1=" + l1)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultBanana.
     */
    public DefaultBanana() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
